@@ -9,7 +9,7 @@ use base 'Mojo::Script';
 
 use Mojo::Server::FCGI::Prefork;
 
-__PACKAGE__->attr(description => (chained => 1, default => <<'EOF'));
+__PACKAGE__->attr('description', default => <<'EOF');
 * Start the fcgi_prefork script. *
 Takes a path as option, by default :3000 will be used.
     fcgi_prefork
